.. Copyright © SixtyFPS GmbH <info@slint.dev>
.. SPDX-License-Identifier: MIT

.. include:: src/introduction/index.md
   :parser: myst_parser.sphinx_

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Introduction

   src/introduction/index.rst
   src/introduction/supported_platforms.md

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Language Reference

   src/language/index.rst
   src/language/concepts/index.rst
   src/language/syntax/index.rst
   src/language/builtins/index.rst
   src/language/widgets/index.rst

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Recipes & Examples

   src/recipes/recipes.md

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Advanced Topics

   src/advanced/debugging_techniques.md
   src/advanced/style.md
   src/advanced/backends_and_renderers.md
